@@ -18,17 +18,18 @@
 
 from __future__ import annotations
 from typing import List, Dict
-from PyQt5.QtWidgets import QSizePolicy
+from PyQt5.Qt import QShowEvent
+from PyQt5.QtCore import Qt
+from magneticalc.QtWidgets2.QDialog2 import QDialog2
+from magneticalc.QtWidgets2.QIconLabel import QIconLabel
+from magneticalc.QtWidgets2.QPushButton2 import QPushButton2
+from magneticalc.QtWidgets2.QTextBrowser2 import QTextBrowser2
 from magneticalc.Constraint import Constraint
-from magneticalc.Debug import Debug
-from magneticalc.Comparison_Types import comparison_type_to_name
+from magneticalc.Comparison_Types import comparison_type_to_name, comparison_name_to_type
 from magneticalc.Config_Group import Config_Collection
-from magneticalc.Norm_Types import norm_type_to_name
-from magneticalc.QDialog2 import QDialog2
-from magneticalc.QIconLabel import QIconLabel
-from magneticalc.QPushButton2 import QPushButton2
-from magneticalc.QTableWidget2 import QTableWidget2
-from magneticalc.QTextBrowser2 import QTextBrowser2
+from magneticalc.Debug import Debug
+from magneticalc.Norm_Types import norm_type_to_name, norm_name_to_type
+from magneticalc.QTableView2 import QTableView2
 from magneticalc.Theme import Theme
 
 
@@ -61,9 +62,16 @@ class Constraint_Editor(QDialog2):
 
         By default, all sampling volume points have relative permeability µ<sub>r</sub> = 1.<br>
         A constraint assigns some other µ<sub>r</sub> to some region of the sampling volume.<br>
-        Constraints of identical permeability are effectively intersected (logical AND).<br>
-        In case of ambiguous constraints, the ones with maximum permeability take precedence.<br>
-        Setting the permeability of some region to zero locally disables the field calculation.
+        Setting the permeability of some region to zero locally disables the field calculation.<br>
+        In case of ambiguous constraints, the ones with maximum permeability take precedence.<br><br>
+
+        Constraints of identical permeability are effectively intersected (logical <code>AND</code> behaviour).<br>
+        <i>Note:</i> You can achieve a logical <code>OR</code> behaviour using <i>De Morgan's laws</i>.<br>
+        (<code>A</code> <b>Not</b> <i>In Range</i>)
+        <code>AND</code>
+        (<code>B</code> <b>Not</b> <i>In Range</i>) =
+        <b>Not</b> (<code>A</code> <i>In Range</i> <code>OR</code> <code>B</code> <i>In Range</i>).<br>
+        This result can then be inverted by letting <code>A</code> and <code>B</code> evaluate to µ<sub>r</sub> = 0.
     """
 
     def __init__(
@@ -86,35 +94,41 @@ class Constraint_Editor(QDialog2):
             first_without_suffix=False
         )
 
-        table_icon_label = QIconLabel("Constraints", "mdi.playlist-edit")
+        table_icon_label = QIconLabel("Constraints", "mdi.playlist-edit", color=Theme.DarkColor)
         table_add_button = QPushButton2("Add constraint", "fa.plus", self.on_table_row_added)
         table_icon_label.addWidget(table_add_button)
         self.addLayout(table_icon_label)
 
-        self.table = QTableWidget2(
+        self.table = QTableView2(
             self.gui,
-            _cell_edited_callback_=self.on_table_cell_edited,
-            _row_deleted_callback_=self.on_table_row_deleted
+            row_prefix="constraint_",
+            col_keys=["Norm", "Comparison", "Min.", "Max.", "µ (relative)"],
+            col_types=self.Constraint_Types,
+            col_options=self.Constraint_Options,
+            on_cell_edited=self.on_table_cell_edited,
+            on_row_deleted=self.on_table_row_deleted
         )
-        self.table.set_horizontal_header(["Norm", "Comparison", "Min.", "Max.", "µ (relative)"])
-        self.table.set_vertical_prefix("constraint_")
-        self.table.set_horizontal_types(self.Constraint_Types)
-        self.table.set_horizontal_options(self.Constraint_Options)
-        self.table.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.addWidget(self.table)
 
-        text_browser = QTextBrowser2(html=self.HTML)
-        self.dialog_shown.connect(text_browser.fit_to_contents)
-        self.addWidget(text_browser)
+        self.text_browser = QTextBrowser2(html=self.HTML)
+        self.addWidget(self.text_browser, alignment=Qt.AlignBottom)
 
         self.addButtons({
             "OK": ("fa.check", self.accept)
         })
 
-        self.dialog_shown.connect(self.table.setFocus)
-
         self._changed = False
 
+    def showEvent(self, event: QShowEvent) -> None:
+        """
+        Gets called when the dialog is opened.
+
+        @param event: QShowEvent
+        """
+        Debug(self, ".showEvent()")
+        self.text_browser.fit_to_contents()
+        self.table.setFocus()
+
     @property
     def changed(self) -> bool:
         """
@@ -143,28 +157,51 @@ class Constraint_Editor(QDialog2):
         """
         Populates the table.
         """
-        self.table.clear_rows()
-        self.table.set_vertical_header([str(i + 1) for i in range(self.get_count())])
-        self.table.set_contents(self.get_constraints())
+        self.table.set_data(
+            data=[list(col_data.values()) for col_data in self.rows],
+            row_keys=[str(i + 1) for i in range(self.rows_count)]
+        )
         self.table.select_last_row(focus=False)
 
     # ------------------------------------------------------------------------------------------------------------------
 
-    def get_count(self) -> int:
+    @property
+    def rows(self) -> List[Dict]:
         """
-        Gets the number of constraints.
+        Gets the list of rows (constraint groups).
 
-        @return: Number of constraints
+        @return: List of rows (constraint groups).
+        """
+        return self._constraint_collection.get_all_groups()
+
+    @property
+    def rows_count(self) -> int:
+        """
+        Gets the number of rows (constraint groups).
+
+        @return: Number of rows (constraint groups)
         """
         return self._constraint_collection.get_count()
 
-    def get_constraints(self) -> List[Dict]:
+    def get_constraints(self) -> List[Constraint]:
         """
         Gets the list of constraints.
 
         @return: List of constraints
         """
-        return self._constraint_collection.get_all_groups()
+        constraints = []
+        for row in self.rows:
+            Debug(self, f".get_constraints(): {row}")
+            constraints.append(
+                Constraint(
+                    norm_name_to_type(row["norm"]),
+                    comparison_name_to_type(row["comparison"]),
+                    row["min"],
+                    row["max"],
+                    row["permeability"]
+                )
+            )
+        return constraints
 
     # ------------------------------------------------------------------------------------------------------------------
 
