@@ -44,7 +44,7 @@ class SidebarRight(QScrollArea):
         @param gui: GUI
         """
         QScrollArea.__init__(self)
-        Debug(self, ": Init")
+        Debug(self, ": Init", init=True)
         self.gui = gui
 
         layout = QVBoxLayout()
