@@ -19,16 +19,15 @@
 from __future__ import annotations
 from typing import Optional, Dict, List, Union
 import numpy as np
-from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QVBoxLayout, QHBoxLayout, QComboBox, QCheckBox
-from magneticalc.QDoubleSpinBox2 import QDoubleSpinBox2
-from magneticalc.QGroupBox2 import QGroupBox2
-from magneticalc.QHLine import QHLine
-from magneticalc.QIconLabel import QIconLabel
-from magneticalc.QLabel2 import QLabel2
-from magneticalc.QPushButton2 import QPushButton2
-from magneticalc.QSpinBox2 import QSpinBox2
-from magneticalc.QTableWidget2 import QTableWidget2
+from magneticalc.QtWidgets2.QDoubleSpinBox2 import QDoubleSpinBox2
+from magneticalc.QtWidgets2.QGroupBox2 import QGroupBox2
+from magneticalc.QtWidgets2.QHLine import QHLine
+from magneticalc.QtWidgets2.QIconLabel import QIconLabel
+from magneticalc.QtWidgets2.QLabel2 import QLabel2
+from magneticalc.QtWidgets2.QPushButton2 import QPushButton2
+from magneticalc.QtWidgets2.QSpinBox2 import QSpinBox2
+from magneticalc.QTableView2 import QTableView2
 from magneticalc.Debug import Debug
 from magneticalc.ModelAccess import ModelAccess
 from magneticalc.Theme import Theme
@@ -86,29 +85,26 @@ class Wire_Widget(QGroupBox2):
 
         @param gui: GUI
         """
-        QGroupBox2.__init__(self, "Wire")
+        QGroupBox2.__init__(self, "Wire", color=Theme.DarkColor)
         Debug(self, ": Init", init=True)
         self.gui = gui
 
         # --------------------------------------------------------------------------------------------------------------
 
-        table_icon_label = QIconLabel("Points", "mdi.vector-square", expand=False)
+        table_icon_label = QIconLabel("Points", "mdi.vector-square", color=Theme.DarkColor, expand=False)
         table_icon_label.addWidget(QLabel2("⟨F2⟩, ⟨ESC⟩", font_size="13px", color=Theme.LiteColor, expand=False))
         table_icon_label.addStretch()
         table_icon_label.addWidget(QPushButton2("", "fa.plus", self.on_table_row_added))
         table_icon_label.addWidget(QLabel2("cm", align_right=True, width=self.UnitsLabelWidth))
         self.addLayout(table_icon_label)
-        self.table = QTableWidget2(
+        self.table = QTableView2(
             self.gui,
-            _cell_edited_callback_=self.on_table_cell_edited,
-            _selection_changed_callback_=self.gui.redraw,
-            _row_deleted_callback_=self.on_table_row_deleted,
-            minimum_rows=2
+            row_count_minimum=2,
+            col_keys=["X", "Y", "Z"],
+            on_cell_edited=self.on_table_cell_edited,
+            on_selection_changed=self.gui.redraw,
+            on_row_deleted=self.on_table_row_deleted
         )
-        self.table.set_horizontal_header(["X", "Y", "Z"])
-        self.table.set_vertical_prefix("")
-        self.table.set_horizontal_types(None)
-        self.table.set_horizontal_options([None, None, None])
         self.addWidget(self.table)
 
         table_total_layout = QHBoxLayout()
@@ -121,7 +117,7 @@ class Wire_Widget(QGroupBox2):
 
         self.addWidget(QHLine())
 
-        stretch_icon_label = QIconLabel("Stretch", "mdi.arrow-all")
+        stretch_icon_label = QIconLabel("Stretch", "mdi.arrow-all", color=Theme.DarkColor)
         stretch_icon_label.addWidget(QPushButton2("", "fa.eraser", self.clear_stretch))
         stretch_icon_label.addWidget(QLabel2("cm", align_right=True, width=self.UnitsLabelWidth))
         self.addLayout(stretch_icon_label)
@@ -147,7 +143,9 @@ class Wire_Widget(QGroupBox2):
 
         self.addWidget(QHLine())
 
-        rotational_symmetry_icon_label = QIconLabel("Rotational Symmetry", "mdi.rotate-3d-variant")
+        rotational_symmetry_icon_label = QIconLabel(
+            "Rotational Symmetry", "mdi.rotate-3d-variant", color=Theme.DarkColor
+        )
         rotational_symmetry_icon_label.addWidget(QPushButton2("", "fa.eraser", self.clear_rotational_symmetry))
         self.addLayout(rotational_symmetry_icon_label)
         rotational_symmetry_layout = QHBoxLayout()
@@ -237,7 +235,7 @@ class Wire_Widget(QGroupBox2):
             QPushButton2(
                 " Replace base points",
                 "mdi.content-copy",
-                lambda: self.set_wire(_points_=self.gui.model.wire.get_points_transformed())
+                lambda: self.set_wire(_points_=self.gui.model.wire.points_transformed)
             )
         )
 
@@ -245,7 +243,7 @@ class Wire_Widget(QGroupBox2):
 
         self.addWidget(QHLine())
 
-        self.addLayout(QIconLabel("Slicer Limit", "mdi.box-cutter"))
+        self.addLayout(QIconLabel("Slicer Limit", "mdi.box-cutter", color=Theme.DarkColor))
         self.slicer_limit_spinbox = QDoubleSpinBox2(
             gui=self.gui,
             minimum=self.SlicerLimitMin,
@@ -271,7 +269,7 @@ class Wire_Widget(QGroupBox2):
 
         self.addWidget(QHLine())
 
-        self.addLayout(QIconLabel("Wire Current", "fa.cog"))
+        self.addLayout(QIconLabel("Wire Current", "fa.cog", color=Theme.DarkColor))
         self.dc_spinbox = QDoubleSpinBox2(
             gui=self.gui,
             minimum=self.DcMin,
@@ -336,7 +334,7 @@ class Wire_Widget(QGroupBox2):
         Debug(self, ".update_labels()", refresh=True)
 
         if self.gui.model.wire.valid:
-            self.sliced_total_label.setText(str(len(self.gui.model.wire.get_points_sliced())))
+            self.sliced_total_label.setText(str(len(self.gui.model.wire.points_sliced)))
         else:
             self.sliced_total_label.setText("N/A")
 
@@ -346,7 +344,7 @@ class Wire_Widget(QGroupBox2):
         """
         Debug(self, ".update_controls()", refresh=True)
 
-        self.indicate_valid(self.gui.model.wire.valid)
+        self.set_color(Theme.MainColor if self.gui.model.wire.valid else Theme.FailureColor)
 
     # ------------------------------------------------------------------------------------------------------------------
 
@@ -356,14 +354,15 @@ class Wire_Widget(QGroupBox2):
         """
         Debug(self, ".update_table()")
 
-        points = [[f"{round(col, 2):+0.02f}" for col in row] for row in self.gui.model.wire.get_points_base()]
+        points = [[f"{col:+0.02f}" for col in row] for row in self.gui.model.wire.points_base]
 
-        self.table.clear_rows()
-        self.table.set_vertical_header([str(i + 1) for i in range(len(self.gui.model.wire.get_points_base()))])
-        self.table.set_contents(points)
+        self.table.set_data(
+            data=points,
+            row_keys=[str(i + 1) for i in range(len(self.gui.model.wire.points_base))]
+        )
         self.table.select_last_row(focus=False)
 
-        self.table_total_label.setText(str(len(self.gui.model.wire.get_points_base())))
+        self.table_total_label.setText(str(len(self.gui.model.wire.points_base)))
 
     def on_table_row_added(self) -> None:
         """
@@ -372,7 +371,7 @@ class Wire_Widget(QGroupBox2):
         Debug(self, ".on_table_row_added()")
 
         # Add a new base point (0, 0, 0) to the wire
-        self.set_wire(_points_=list(self.gui.model.wire.get_points_base()) + [np.zeros(3)])
+        self.set_wire(_points_=list(self.gui.model.wire.points_base) + [np.zeros(3)])
         self.table.select_last_row()
 
     def on_table_cell_edited(self, value: float, row: int, column: int) -> None:
@@ -383,7 +382,7 @@ class Wire_Widget(QGroupBox2):
         @param row: Row index
         @param column: Column index
         """
-        points = self.gui.model.wire.get_points_base()
+        points = self.gui.model.wire.points_base
         points[row][column] = value
         self.set_wire(_points_=points)
 
@@ -396,7 +395,7 @@ class Wire_Widget(QGroupBox2):
         Debug(self, ".on_table_row_deleted()")
 
         # Delete the wire base point at the given index
-        self.set_wire(_points_=np.delete(self.gui.model.wire.get_points_base(), index, axis=0))
+        self.set_wire(_points_=np.delete(self.gui.model.wire.points_base, index, axis=0))
 
     # ------------------------------------------------------------------------------------------------------------------
 
@@ -555,7 +554,7 @@ class Wire_Widget(QGroupBox2):
             if should_update_rotational_symmetry_controls:
                 self.update_rotational_symmetry(rotational_symmetry=rotational_symmetry)
 
-            self.transformed_total_label.setText(str(len(self.gui.model.wire.get_points_transformed())))
+            self.transformed_total_label.setText(str(len(self.gui.model.wire.points_transformed)))
 
             if readjust_sampling_volume:
                 self.gui.sidebar_left.sampling_volume_widget.readjust()
